// SCORM model
function initScormModel(proxyScorm) {
    // Get model from scorm lib
    let model = p2l.proxyscorm.scormModel;

    if (window.API != null) {
        let success = false;

        if (scormVersion === "1.2") {
            success = window.API.LMSInitialize("");
        } else {
            success = window.API.Initialize("");
        }

        if (success === "true") {
            // Get values
            Object.keys(model).forEach(function (key) {
                model[key] = getValue(key);
            });

            let scormMessage = {
                action: "LMSInitScormModel",
                data: model
            };

            // Send model to SCORM Launcher
            proxyScorm.contentWindow.postMessage(
                JSON.stringify(scormMessage),
                remoteHost
            );
        } else {
            alert("Failed to initilize SCORM");
        }
    }
}

// Get SCORM Value
function getValue(param) {
    if (scormVersion === "1.2") {
        return window.API.LMSGetValue(param);
    } else {
        return window.API.GetValue(param);
    }
}

// EventListeners for PostMessage
function initEventListenerForPostMsg() {
    // PostMessage for cross domain
    // Create IE + others compatible event handler
    var eventMethod = window.addEventListener
        ? "addEventListener"
        : "attachEvent";
    var eventer = window[eventMethod];
    var messageEvent = eventMethod == "attachEvent" ? "onmessage" : "message";

    // Listen to message from parent window
    eventer(
        messageEvent,
        function (e) {
            // Check Origin before processing call (remoteHost from Proxy Package)
            console.log("(Proxy) Message recived from", e.origin);

            if (typeof remoteHost === "undefined") {
                console.log("Remotehost not defined");
                return;
            }

            if (e.origin !== remoteHost) {
                console.log("Origin: " + e.origin + " invalid");
                return;
            }

            // Scorm message (contains param and data)
            var scormMessage = JSON.parse(e.data);

            switch (scormMessage.action) {
                case "LMSInitialize":
                    console.log("(Proxy) LMSInitialize", scormMessage);
                    API.LMSInitialize("");
                    break;
                case "LMSSetValue":
                    console.log("(Proxy) LMSSetValue", scormMessage);
                    API.LMSSetValue(scormMessage.param, scormMessage.data);
                    break;
                case "LMSGetValue":
                    console.log("(Proxy) LMSGetValue", scormMessage);
                    API.LMSGetValue(scormMessage.param);
                    break;
                case "LMSFinish":
                    console.log("(Proxy) LMSFinish", scormMessage);
                    API.LMSFinish("");
                    break;
            }
        },
        false
    );
}

// Call from index
function onLoad() {
    if (scormVersion === "1.2") {
        // Set API 1.2
        window.API = p2l.proxyscorm.API();
    } else {
        // Set API 2004
        window.API_1484_11 = p2l.proxyscorm.API();
    }

    // SCORM Launcher
    let proxyScorm = document.getElementById("proxyScorm");

    // Default proxy scorm launcher
    let proxy_launcher_url = remoteHost;

    // Current host
    let currentHost = window.location.protocol + "//" + "" + window.location.host;

    if (currentHost.indexOf(".plan2learn") > 1) {
        // Internal (same main domain)
        proxy_launcher_url = currentHost;
    } else {
        // External
        initEventListenerForPostMsg();

        // Init SCORM Model on load
        proxyScorm.onload = function () {
            initScormModel(proxyScorm);
        };
    }

    // Check if proxy is loaded within p2l (guid is used to get the responsible, on errors)
    var guid = p2l.proxyscorm.getUrlParameter("spg", parent);
    if (guid) {
        guid = "&guid=" + guid
    }

    // Set URL
    proxyScorm.src =
        proxy_launcher_url +
        "/scorm/proxy-launcher/?api=" +
        scormkey +
        "&host=" +
        encodeURIComponent(currentHost) +
        guid;
};